@@ -1,11 +1,11 @@
 from dataclasses import dataclass
-from typing import Any, List, Optional, Union
+from typing import Callable, List, Optional, Union, TYPE_CHECKING
 import inspect
 import itertools
-import warnings
 import types
 
 import requests
+from flask import Flask
 
 from flask_discord_interactions.models import (
     LoadableDataclass,
@@ -21,6 +21,9 @@ from flask_discord_interactions.models import (
     Option,
 )
 
+if TYPE_CHECKING:
+    from flask_discord_interactions.discord import DiscordInteractions
+
 
 @dataclass
 class Context(LoadableDataclass):
@@ -36,6 +39,8 @@ class Context(LoadableDataclass):
     id
         The unique ID (snowflake) of this interaction.
     type
+        The :class:`InteractionType` of this interaction.
+    command_type
         The :class:`ApplicationCommandType` of this interaction.
     token
         The token to use when sending followup messages.
@@ -80,6 +85,7 @@ class Context(LoadableDataclass):
     author: Union[Member, User] = None
     id: str = None
     type: int = None
+    command_type: int = None
     token: str = None
     channel_id: str = None
     guild_id: str = None
@@ -96,8 +102,8 @@ class Context(LoadableDataclass):
     locale: Optional[str] = None
     guild_locale: Optional[str] = None
     app_permissions: Optional[str] = None
-    app: Any = None
-    discord: Any = None
+    app: Flask = None
+    discord: "DiscordInteractions" = None
 
     custom_id: str = None
     primary_id: str = None
@@ -107,7 +113,9 @@ class Context(LoadableDataclass):
     target: Union[User, Message] = None
 
     @classmethod
-    def from_data(cls, discord=None, app=None, data={}):
+    def from_data(
+        cls, discord: "DiscordInteractions" = None, app: Flask = None, data={}
+    ):
         if data is None:
             data = {}
 
@@ -120,7 +128,9 @@ class Context(LoadableDataclass):
             app=app,
             discord=discord,
             id=data.get("id"),
-            type=data.get("data", {}).get("type") or ApplicationCommandType.CHAT_INPUT,
+            type=data.get("type"),
+            command_type=data.get("data", {}).get("type")
+            or ApplicationCommandType.CHAT_INPUT,
             token=data.get("token"),
             channel_id=data.get("channel_id"),
             guild_id=data.get("guild_id"),
@@ -154,7 +164,7 @@ class Context(LoadableDataclass):
         else:
             return self.frozen_auth_headers
 
-    def parse_author(self, data):
+    def parse_author(self, data: dict):
         """
         Parse the author (invoking user) of this interaction.
 
@@ -174,7 +184,7 @@ class Context(LoadableDataclass):
         else:
             self.author = None
 
-    def parse_message(self, data):
+    def parse_message(self, data: dict):
         """
         Parse the message out of in interaction.
 
@@ -245,12 +255,12 @@ class Context(LoadableDataclass):
         For User and Message commands, the target is the relevant user or
         message. This method sets the `ctx.target` field.
         """
-        if self.type == ApplicationCommandType.USER:
+        if self.command_type == ApplicationCommandType.USER:
             if self.target_id in self.members:
                 self.target = self.members[self.target_id]
             else:
                 self.target = self.users[self.target_id]
-        elif self.type == ApplicationCommandType.MESSAGE:
+        elif self.command_type == ApplicationCommandType.MESSAGE:
             self.target = self.messages[self.target_id]
         else:
             self.target = None
@@ -263,11 +273,11 @@ class Context(LoadableDataclass):
         Create the arguments which will be passed to the function when the
         :class:`Command` is invoked.
         """
-        if self.type == ApplicationCommandType.CHAT_INPUT:
+        if self.command_type == ApplicationCommandType.CHAT_INPUT:
             return self.create_args_chat_input()
-        elif self.type == ApplicationCommandType.USER:
+        elif self.command_type == ApplicationCommandType.USER:
             return [self.target], {}
-        elif self.type == ApplicationCommandType.MESSAGE:
+        elif self.command_type == ApplicationCommandType.MESSAGE:
             return [self.target], {}
 
     def create_args_chat_input(self):
@@ -329,14 +339,14 @@ class Context(LoadableDataclass):
 
         return create_args_recursive({"options": self.options}, self.resolved)
 
-    def create_handler_args(self, handler):
+    def create_handler_args(self, handler: Callable):
         """
         Create the arguments which will be passed to the function when a
         custom ID handler is invoked.
 
         Parameters
         ----------
-        handler
+        handler: Callable
             The custom ID handler to create arguments for.
         """
 
@@ -371,14 +381,14 @@ class Context(LoadableDataclass):
     def create_autocomplete_args(self):
         return [Option.from_data(option) for option in self.options]
 
-    def followup_url(self, message=None):
+    def followup_url(self, message: str = None):
         """
         Return the followup URL for this interaction. This URL can be used to
         send a new message, or to edit or delete an existing message.
 
         Parameters
         ----------
-        message
+        message: str
             The ID of the message to edit or delete.
             If None, sends a new message.
             If "@original", refers to the original message.
@@ -393,15 +403,15 @@ class Context(LoadableDataclass):
 
         return url
 
-    def edit(self, updated, message="@original"):
+    def edit(self, updated: Union[Message, str], message: str = "@original"):
         """
         Edit an existing message.
 
         Parameters
         ----------
-        updated
+        updated: Union[Message, str]
             The updated Message to edit the message to.
-        message
+        message: str
             The ID of the message to edit.
             If omitted, edits the original message.
         """
@@ -411,19 +421,21 @@ class Context(LoadableDataclass):
         if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
             return
 
+        response, mimetype = updated.encode(followup=True)
         updated = requests.patch(
             self.followup_url(message),
-            **updated.dump_multipart(),
+            data=response,
+            headers={"Content-Type": mimetype},
         )
         updated.raise_for_status()
 
-    def delete(self, message="@original"):
+    def delete(self, message: str = "@original"):
         """
         Delete an existing message.
 
         Parameters
         ----------
-        message
+        message: str
             The ID of the message to delete.
             If omitted, deletes the original message.
         """
@@ -434,13 +446,13 @@ class Context(LoadableDataclass):
         response = requests.delete(self.followup_url(message))
         response.raise_for_status()
 
-    def send(self, message):
+    def send(self, message: Union[Message, str]):
         """
         Send a new followup message.
 
         Parameters
         ----------
-        message
+        message: Union[Message, str]
             The :class:`Message` to send as a followup message.
         """
 
@@ -449,12 +461,22 @@ class Context(LoadableDataclass):
 
         message = Message.from_return_value(message)
 
-        message = requests.post(self.followup_url(), **message.dump_multipart())
+        response, mimetype = message.encode(followup=True)
+        message = requests.post(
+            self.followup_url(), data=response, headers={"Content-Type": mimetype}
+        )
         message.raise_for_status()
         return message.json()["id"]
 
-    def get_command(self, command_name=None):
-        "Get the ID of a command by name."
+    def get_command(self, command_name: str = None):
+        """
+        Get the ID of a command by name.
+
+        Parameters
+        ----------
+        command_name: str
+            The name of the command to get the ID of.
+        """
         if command_name is None:
             return self.command_id
         else:
@@ -463,36 +485,6 @@ class Context(LoadableDataclass):
             except KeyError:
                 raise ValueError(f"Unknown command: {command_name}")
 
-    def overwrite_permissions(self, permissions, command=None):
-        """
-        Overwrite the permission overwrites for this command.
-
-        Parameters
-        ----------
-        permissions
-            The new list of permission overwrites.
-        command
-            The name of the command to overwrite permissions for. If omitted,
-            overwrites for the invoking command.
-        """
-
-        url = (
-            f"{self.app.config['DISCORD_BASE_URL']}/"
-            f"applications/{self.app.config['DISCORD_CLIENT_ID']}/"
-            f"guilds/{self.guild_id}/"
-            f"commands/{self.get_command(command)}/permissions"
-        )
-
-        data = [permission.dump() for permission in permissions]
-
-        if self.app.config["DONT_REGISTER_WITH_DISCORD"]:
-            return
-
-        response = requests.put(
-            url, headers=self.auth_headers, json={"permissions": data}
-        )
-        response.raise_for_status()
-
     def freeze(self):
         "Return a copy of this Context that can be pickled for RQ and Celery."
 
@@ -512,8 +504,15 @@ class Context(LoadableDataclass):
         return new_context
 
     def get_component(self, component_id: str):
-        """Get a Component, only available for Modal Contexts.
-        If the component was not found, raises a LookupError."""
+        """
+        Get a Component, only available for Modal Contexts.
+        If the component was not found, raises a LookupError.
+
+        Parameters
+        ----------
+        component_id: str
+            The ID of the component to look up.
+        """
         if not self.components:
             raise ValueError("This Context does not have any components.")
         for action_row in self.components:
@@ -538,15 +537,15 @@ class AsyncContext(Context):
 
         self.session = self.app.discord_client_session
 
-    async def edit(self, updated, message="@original"):
+    async def edit(self, updated: Union[str, Message], message: str = "@original"):
         """
         Edit an existing message.
 
         Parameters
         ----------
-        updated
+        updated: Union[str, Message]
             The updated Message to edit the message to.
-        message
+        message: str
             The ID of the message to edit.
             If omitted, edits the original message.
         """
@@ -556,17 +555,20 @@ class AsyncContext(Context):
         if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
             return
 
+        response, mimetype = updated.encode(followup=True)
         await self.session.patch(
-            self.followup_url(message), json=updated.dump_followup()
+            self.followup_url(message),
+            data=response,
+            headers={"Content-Type": mimetype},
         )
 
-    async def delete(self, message="@original"):
+    async def delete(self, message: str = "@original"):
         """
         Delete an existing message.
 
         Parameters
         ----------
-        message
+        message: str
             The ID of the message to delete.
             If omitted, deletes the original message.
         """
@@ -576,13 +578,13 @@ class AsyncContext(Context):
 
         await self.session.delete(self.followup_url(message))
 
-    async def send(self, message):
+    async def send(self, message: Union[Message, str]):
         """
         Send a new followup message.
 
         Parameters
         ----------
-        message
+        message: Union[Message, str]
             The Message object to send as a followup message.
         """
 
@@ -591,54 +593,10 @@ class AsyncContext(Context):
         if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
             return
 
+        response, mimetype = message.encode(followup=True)
         async with self.session.post(
-            self.followup_url(), **message.dump_multipart()
+            self.followup_url(),
+            data=response,
+            headers={"Content-Type": mimetype},
         ) as message:
             return (await message.json())["id"]
-
-    async def overwrite_permissions(self, permissions, command=None):
-        """
-        Overwrite the permission overwrites for this command.
-
-        Parameters
-        ----------
-        permissions
-            The new list of permission overwrites.
-        command
-            The name of the command to overwrite permissions for. If omitted,
-            overwrites for the invoking command.
-        """
-
-        url = (
-            f"{self.app.config['DISCORD_BASE_URL']}/"
-            f"applications/{self.app.config['DISCORD_CLIENT_ID']}/"
-            f"guilds/{self.guild_id}/"
-            f"commands/{self.get_command(command)}/permissions"
-        )
-
-        data = [permission.dump() for permission in permissions]
-
-        if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
-            return
-
-        await self.session.put(
-            url, headers=self.auth_headers, json={"permissions": data}
-        )
-
-    async def close(self):
-        """
-        Deprecated as of v1.0.2.
-
-        Previously, this closed the AsyncContext's aiohttp ClientSession that
-        was used to send followup messages. This is no longer necessary, as
-        this library now maintains a single ClientSession for the entire
-        application.
-        """
-
-        warnings.warn(
-            "Deprecated! AsyncContext.close is a no-op. "
-            "Since v1.0.2, only one aiohttp ClientSession is created "
-            "for all requests to Discord for the app. "
-            "Thus, there is no need to close the AsyncContext. ",
-            DeprecationWarning,
-        )
