@@ -1,3 +1,4 @@
+import json
 from typing import Union
 from flask_discord_interactions.models.message import ResponseType
 from flask_discord_interactions.models.option import Choice
@@ -7,7 +8,7 @@ class Autocomplete:
     """
     Represents the type of an option that can be autocompleted.
 
-    Attributes
+    Parameters
     ----------
     t
         The underlying type of the option.
@@ -21,7 +22,7 @@ class AutocompleteResult:
     """
     Represents the result of an autocomplete handler.
 
-    Attributes
+    Parameters
     ----------
     choices
         A dict mapping the displayed name of each choice to its value passed to
@@ -31,21 +32,32 @@ class AutocompleteResult:
     def __init__(self, choices=[]):
         self.choices = choices
 
-    def dump(self):
-        "Return this result as a complete interaction response."
-        return {
+    def encode(self):
+        """
+        Return this result as a complete interaction response.
+
+        Returns
+        -------
+        str
+            The encoded JSON object.
+        str
+            The mimetype of the response (``application/json``).
+        """
+        data = {
             "type": ResponseType.APPLICATION_COMMAND_AUTOCOMPLETE_RESULT,
             "data": {"choices": self.choices},
         }
 
+        return json.dumps(data), "application/json"
+
     @staticmethod
     def from_return_value(value: Union[dict, list, "AutocompleteResult"]):
         """
         Converts the return value of an autocomplete handler to an
         AutocompleteResult.
 
-        Paramters
-        ---------
+        Parameters
+        ----------
         value
             The return value of an autocomplete handler.
 
