@@ -24,7 +24,7 @@ class Option:
     """
     Represents an option provided to a slash command.
 
-    Attributes
+    Parameters
     ----------
     name
         The name of the option.
@@ -105,8 +105,10 @@ class Option:
                 raise ValueError(f"Unknown type {self.type}")
 
     @classmethod
-    def from_data(cls, data):
-        "Load this option from incoming Interaction data."
+    def from_data(cls, data: dict):
+        """
+        Load this option from incoming Interaction data.
+        """
         return cls(
             name=data["name"],
             type=data["type"],
@@ -115,7 +117,14 @@ class Option:
         )
 
     def dump(self):
-        "Return this option as as a dict for registration with Discord."
+        """
+        Return this option as as a dict for registration with Discord.
+
+        Returns
+        -------
+        dict
+            A dict representing this option.
+        """
         data = {
             "name": self.name,
             "name_localizations": self.name_localizations,
@@ -132,7 +141,9 @@ class Option:
             "autocomplete": self.autocomplete,
         }
         if self.choices is not None:
-            data["choices"] = [(c.dump() if isinstance(c, Choice) else c) for c in self.choices]
+            data["choices"] = [
+                (c.dump() if isinstance(c, Choice) else c) for c in self.choices
+            ]
         return data
 
 
@@ -153,7 +164,14 @@ class Choice:
     name_localizations: Optional[dict] = None
 
     def dump(self):
-        "Return this choice as a dict for registration with Discord."
+        """
+        Return this choice as a dict for registration with Discord.
+
+        Returns
+        -------
+        dict
+            A dict representing this choice.
+        """
         data = {
             "name": self.name,
             "value": self.value,
